Flask-SocketIO-Chat
===================

application that demonstrates how to structure a Flask-SocketIO application.

To run this application install the requirements in a virtual environment, run `python chat.py` and visit `http://localhost:5000` on one or more browser tabs.

    $ python chat.py
